==> hermes-5.5.0.11.tar.gz: hermes-5.5.0.11/spec/models/reservation_holder_spec.rb <==
require 'rails_helper'

RSpec.describe Hermes::ReservationHolder, type: :model do
  it 'has a valid factory' do
    expect(FactoryBot.build(:reservation_holder)).to be_valid
  end

  
  
  describe 'update_readers' do
    let(:l1) { create(:lessor)}
    let(:l2) { create(:lessor)}
    let(:l3) { create(:lessor)}
    let(:user1) { create(:user, group_ids: [l1.manager_group_id])}
    let(:user2) { create(:user, group_ids: [l2.manager_group_id])}
    let(:user3) { create(:user, group_ids: [l3.manager_group_id])}
    let!(:rh_public) { create(:reservation_holder, name: 'public', public_read: true)}
    let!(:rh_lessors) { create(:reservation_holder, name: 'lessors', lessors: [l1, l2])}

    it 'public reservation holder works' do
      expect(rh_public.reload.readers.include?(l1.id)).to eq false
      expect(rh_public.reload.readable_by?(user1)).to eq true
      expect(rh_public.reload.readable_by?(user2)).to eq true
      expect(rh_public.reload.readable_by?(user3)).to eq true
    end

    it 'private reservation holder works' do
      expect(rh_lessors.reload.readers.include?("g_#{l1.manager_group_id}")).to eq true
      expect(rh_lessors.reload.readable_by?(user1)).to eq true
      expect(rh_lessors.reload.readable_by?(user2)).to eq true
      expect(rh_lessors.reload.readable_by?(user3)).to eq false
    end
  end

  describe 'find_entities_from_siren' do 
    let!(:eA1) { create(:entity, siren: 'A00000001')}
    let!(:eA2) { create(:entity, parent_id: eA1.id, siren: 'A00000002')}
    let!(:eA3) { create(:entity, parent_id: eA2.id, siren: 'A00000003')}
    let!(:eA31) { create(:entity, parent_id: eA2.id, siren: 'A00000031')}
    let!(:eB1) { create(:entity, siren: eA1.siren)}

    let!(:rh_A) { create(:reservation_holder, name: 'entityA', siren: [eA2.siren, eA3.siren] )}
    let!(:rh_AB) { create(:reservation_holder, name: 'entityAB', siren: [eA1.siren, 'other siren'] )}
    let!(:rh_no_entity_siren) { create(:reservation_holder, name: 'no_entity_siren', siren: ['no_entity_siren'] )}

    it 'no siren found' do 
      expect(Hermes::ReservationHolder.find_entities_from_siren('test')).to eq(nil)
    end 

    it 'no entity found' do 
      expect(Hermes::ReservationHolder.find_entities_from_siren('no_entity_siren')).to eq([])
    end 

    it 'abro A' do 
      expect(Hermes::ReservationHolder.find_entities_from_siren(eA2.siren).length).to eq(4)
    end 

    it 'abro AB' do 
      expect(Hermes::ReservationHolder.find_entities_from_siren(eA1.siren).length).to eq(5)
    end 

  end 

end

==> hermes-6.0.2.50.tar.gz: hermes-6.0.2.50/spec/models/reservation_holder_spec.rb <==
require 'rails_helper'

RSpec.describe Hermes::ReservationHolder, type: :model do
  it 'has a valid factory' do
    expect(FactoryBot.build(:reservation_holder)).to be_valid
  end

  
  
  describe 'update_readers' do
    let(:l1) { create(:lessor)}
    let(:l2) { create(:lessor)}
    let(:l3) { create(:lessor)}
    let(:user1) { create(:user, group_ids: [l1.manager_group_id])}
    let(:user2) { create(:user, group_ids: [l2.manager_group_id])}
    let(:user3) { create(:user, group_ids: [l3.manager_group_id])}
    let!(:rh_public) { create(:reservation_holder, name: 'public', public_read: true)}
    let!(:rh_lessors) { create(:reservation_holder, name: 'lessors', lessors: [l1, l2])}

    it 'public reservation holder works' do
      expect(rh_public.reload.readers.include?(l1.id)).to eq false
      expect(rh_public.reload.readable_by?(user1)).to eq true
      expect(rh_public.reload.readable_by?(user2)).to eq true
      expect(rh_public.reload.readable_by?(user3)).to eq true
    end

    it 'private reservation holder works' do
      expect(rh_lessors.reload.readers.include?("g_#{l1.manager_group_id}")).to eq true
      expect(rh_lessors.reload.readable_by?(user1)).to eq true
      expect(rh_lessors.reload.readable_by?(user2)).to eq true
      expect(rh_lessors.reload.readable_by?(user3)).to eq false
    end
  end

  describe 'find_entities_from_siren' do 
    let!(:eA1) { create(:entity, siret: 'A0000000101234')}
    let!(:eA2) { create(:entity, parent_id: eA1.id, siret: 'A0000000201234')}
    let!(:eA3) { create(:entity, parent_id: eA2.id, siret: 'A0000000301234')}
    let!(:eA31) { create(:entity, parent_id: eA2.id, siret: 'A0000003101234')}
    let!(:eB1) { create(:entity, siret: eA1.siret)}

    let!(:rh_A) { create(:reservation_holder, name: 'entityA', siren: [eA2.siren, eA3.siren] )}
    let!(:rh_AB) { create(:reservation_holder, name: 'entityAB', siren: [eA1.siren, 'other siren'] )}
    let!(:rh_no_entity_siren) { create(:reservation_holder, name: 'no_entity_siren', siren: ['no_entity_siren'] )}

    it 'no siren found' do 
      expect(Hermes::ReservationHolder.find_entities_from_siren('test')).to eq(nil)
    end 

    it 'no entity found' do 
      expect(Hermes::ReservationHolder.find_entities_from_siren('no_entity_siren')).to eq([])
    end 

    it 'abro A' do 
      expect(Hermes::ReservationHolder.find_entities_from_siren(eA2.siren).length).to eq(4)
    end 

    it 'abro AB' do 
      expect(Hermes::ReservationHolder.find_entities_from_siren(eA1.siren).length).to eq(5)
    end 

  end 

end
